annoy_close_index: Close any loaded Annoy handle cached inside a...

View source: R/annoy_interface.R

annoy_close_indexR Documentation

Close any loaded Annoy handle cached inside a bigannoy_index

Description

Close any loaded Annoy handle cached inside a bigannoy_index

Usage

annoy_close_index(index)

Arguments

index

A bigannoy_index.

Value

index, invisibly.


bigANNOY documentation built on April 1, 2026, 9:07 a.m.