annoy_is_loaded: Check whether an index currently has a loaded in-memory...

View source: R/annoy_interface.R

annoy_is_loadedR Documentation

Check whether an index currently has a loaded in-memory handle

Description

Check whether an index currently has a loaded in-memory handle

Usage

annoy_is_loaded(index)

Arguments

index

A bigannoy_index.

Value

TRUE when a live native or debug-only handle is cached, otherwise FALSE.


bigANNOY documentation built on April 1, 2026, 9:07 a.m.