Check whether an index currently has a loaded in-memory handle
Source:R/annoy_interface.R
annoy_is_loaded.RdCheck whether an index currently has a loaded in-memory handle
R/annoy_interface.R
annoy_is_loaded.RdCheck whether an index currently has a loaded in-memory handle