annoy_validate_index: Validate a persisted Annoy index and its sidecar metadata

View source: R/annoy_interface.R

annoy_validate_indexR Documentation

Validate a persisted Annoy index and its sidecar metadata

Description

Validate a persisted Annoy index and its sidecar metadata

Usage

annoy_validate_index(index, strict = TRUE, load = TRUE, prefault = NULL)

Arguments

index

A bigannoy_index.

strict

Whether failed validation checks should raise an error.

load

Whether to also verify that the index can be loaded successfully.

prefault

Optional logical override used when load = TRUE.

Value

A list containing valid, checks, and the normalized index.


bigANNOY documentation built on April 1, 2026, 9:07 a.m.