View source: R/annoy_interface.R
| annoy_validate_index | R Documentation |
Validate a persisted Annoy index and its sidecar metadata
annoy_validate_index(index, strict = TRUE, load = TRUE, prefault = NULL)
index |
A |
strict |
Whether failed validation checks should raise an error. |
load |
Whether to also verify that the index can be loaded successfully. |
prefault |
Optional logical override used when |
A list containing valid, checks, and the normalized index.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.