View source: R/benchmark_interface.R
| benchmark_annoy_vs_rcppannoy | R Documentation |
Run the same Annoy build and search task through bigANNOY and through a
direct dense RcppAnnoy baseline. The comparison reports both speed metrics
and data-volume metrics such as reference bytes, query bytes, and generated
index size.
benchmark_annoy_vs_rcppannoy(
x = NULL,
query = NULL,
n_ref = 2000L,
n_query = 200L,
n_dim = 20L,
k = 10L,
n_trees = 50L,
metric = "euclidean",
search_k = -1L,
seed = 42L,
build_seed = seed,
build_threads = -1L,
block_size = annoy_default_block_size(),
backend = getOption("bigANNOY.backend", "cpp"),
exact = TRUE,
filebacked = FALSE,
path_dir = tempdir(),
keep_files = FALSE,
output_path = NULL,
load_mode = "eager"
)
x |
Optional benchmark reference input. Supply |
query |
Optional benchmark query input. Supply |
n_ref |
Number of synthetic reference rows to generate when |
n_query |
Number of synthetic query rows to generate when |
n_dim |
Number of synthetic columns to generate when |
k |
Number of neighbours to return. |
n_trees |
Number of Annoy trees to build. |
metric |
Annoy metric. One of |
search_k |
Annoy search budget. |
seed |
Random seed used for synthetic data generation and, by default, for the Annoy build seed. |
build_seed |
Optional Annoy build seed. Defaults to |
build_threads |
Native Annoy build-thread setting. |
block_size |
Build/search block size. |
backend |
Requested bigANNOY backend. |
exact |
Logical flag controlling whether to benchmark the exact
Euclidean baseline with |
filebacked |
Logical flag; if |
path_dir |
Directory where temporary Annoy and optional file-backed benchmark files should be written. |
keep_files |
Logical flag; if |
output_path |
Optional CSV path where the benchmark summary should be written. |
load_mode |
Whether the benchmarked index should be returned
metadata-only until first search ( |
A list with a two-row summary data frame, one row for bigANNOY
and one for direct RcppAnnoy, plus benchmark metadata and any validation
report produced for the bigANNOY index.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.